@@ -7,5 +7,5 @@ coverage_header <- c("topic_key", "population_key", "population_name", "populati
 coverage_header_keys_only <- c("topic_key", "population_key", "period_key", "layer_key")
 data_header_long <- c("geoid", "topic_key", "population_key", "period_key", "layer_key", "value", "standardError")
 layers_header <- c("layer_name", "layer_key", "layer_description", "layer_url")
-layer_header <- c("layer_key", "geoid", "name", "population", "state","notes", "geometry")
+layer_header <- c("geoid", "layer_key", "name", "population", "state", "notes", "geometry")
 point_layers_header <- c("point_layer_name", "point_layer_uuid", "point_layer_description")
